return <<'END';
0024	
002b	
003c	003e
005e	
0060	
007c	
007e	
00a2	00a9
00ac	
00ae	00b1
00b4	
00b6	
00b8	
00d7	
00f7	
02b9	02ba
02c2	02cf
02d2	02df
02e5	02ed
0374	0375
0384	0385
0482	
06e9	
06fd	06fe
09f2	09f3
09fa	
0b70	
0e3f	
0f01	0f03
0f13	0f17
0f1a	0f1f
0f34	
0f36	
0f38	
0fbe	0fc5
0fc7	0fcc
0fcf	
17db	
1fbd	
1fbf	1fc1
1fcd	1fcf
1fdd	1fdf
1fed	1fef
1ffd	1ffe
2044	
207a	207c
208a	208c
20a0	20af
2100	2101
2103	2106
2108	2109
2114	
2116	2118
211e	2123
2125	
2127	
2129	
212e	
2132	
213a	
2190	21f3
2200	22f1
2300	2328
232b	237b
237d	239a
2400	2426
2440	244a
249c	24e9
2500	2595
25a0	25f7
2600	2613
2619	2671
2701	2704
2706	2709
270c	2727
2729	274b
274d	
274f	2752
2756	
2758	275e
2761	2767
2794	
2798	27af
27b1	27be
2800	28ff
2e80	2e99
2e9b	2ef3
2f00	2fd5
2ff0	2ffb
3004	
3012	3013
3020	
3036	3037
303e	303f
309b	309c
3190	3191
3196	319f
3200	321c
322a	3243
3260	327b
327f	
328a	32b0
32c0	32cb
32d0	32fe
3300	3376
337b	33dd
33e0	33fe
a490	a4a1
a4a4	a4b3
a4b5	a4c0
a4c2	a4c4
a4c6	
fb29	
fe62	
fe64	fe66
fe69	
ff04	
ff0b	
ff1c	ff1e
ff3e	
ff40	
ff5c	
ff5e	
ffe0	ffe6
ffe8	ffee
fffc	fffd
END
